@@ -3,13 +3,13 @@ os.environ['ANSI_COLORS_DISABLED']="1"
 import shutil
 import fire
 from codemaker.makecode import gencode,write_yaml
-DEFAULT_MAKER_FILE='maker.yaml'
+DEFAULT_MAKER_FILENAME='maker.yaml'
 class CLI:
     def hi(cls):
         print('Hi, I am codemaker.'.center(50, '*'))
     def maketmpl(self,target=None,overwrite=False):
         if not target:
-            target=DEFAULT_MAKER_FILE
+            target=DEFAULT_MAKER_FILENAME
         if os.path.exists(target) and not overwrite:
             raise FileExistsError(target)
         write_yaml(dict(
@@ -18,8 +18,8 @@ class CLI:
                 foo='foo value'
             ),
         ),target)
-    def gencode(self,src,dst,maker=DEFAULT_MAKER_FILE,overwrite=False,exists_ok=True):
-        return gencode(src,dst,maker,overwrite=overwrite,exists_ok=exists_ok)
+    def gencode(self,src,dst,maker=DEFAULT_MAKER_FILENAME,overwrite=False,exists_ok=True,**kwargs):
+        return gencode(src,dst,maker,overwrite=overwrite,exists_ok=exists_ok,**kwargs)
 
 def main():
     fire.Fire(CLI())
