@@ -80,8 +80,9 @@ class CodeGenerator:
 
 
 
-def gencode(src,dst,tmpl,overwrite=False,exists_ok=False):
+def gencode(src,dst,tmpl,overwrite=False,exists_ok=False,**kwargs):
     cfg=read_yaml(tmpl)
+    cfg.update(kwargs)
     cg=CodeGenerator(
         extensions=cfg['exts'],
     )
